==> jc-1.4.0.tar.gz: polyglot/ext/jl/ast/Ext__5fc.h <==
// public abstract class polyglot.ext.jl.ast.Ext_c

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5b47f28ee45bd40c polyglot_ext_jl_ast_Ext__5fc

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_jl_ast_Ext__5fc_H_
#define _JC_polyglot_ext_jl_ast_Ext__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Ext$object;
struct _jc_polyglot_ast_Node$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_Ext__5fc$sub_refs	_jc_polyglot_ext_jl_ast_Ext__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_Ext__5fc$sub_nonrefs	_jc_polyglot_ext_jl_ast_Ext__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_Ext__5fc$refs	_jc_polyglot_ext_jl_ast_Ext__5fc$refs;
typedef struct _jc_polyglot_ext_jl_ast_Ext__5fc$nonrefs	_jc_polyglot_ext_jl_ast_Ext__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_Ext__5fc$object	_jc_polyglot_ext_jl_ast_Ext__5fc$object;

typedef const struct _jc_polyglot_ext_jl_ast_Ext__5fc$vmethods	_jc_polyglot_ext_jl_ast_Ext__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_Ext__5fc$vtable	_jc_polyglot_ext_jl_ast_Ext__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_Ext__5fc$vtype	_jc_polyglot_ext_jl_ast_Ext__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_Ext__5fc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *);
extern void _jc_polyglot_ext_jl_ast_Ext__5fc$method$_init$35a4291096b596b0(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_ext_jl_ast_Ext__5fc$method$copy$2119f530248e04c9(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_Ext__5fc$method$ext$8696abb67847e2d8(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_Ext__5fc$method$ext$7f9846d7beff599f(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *, struct _jc_object *);
extern void _jc_polyglot_ext_jl_ast_Ext__5fc$method$init$ee9f9a61758512fe(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_Ext__5fc$method$node$d01193f9f5e593ba(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_ast_Ext__5fc$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_ast_Ext__5fc$method_info$copy$2119f530248e04c9;
extern _jc_method _jc_polyglot_ext_jl_ast_Ext__5fc$method_info$ext$8696abb67847e2d8;
extern _jc_method _jc_polyglot_ext_jl_ast_Ext__5fc$method_info$ext$7f9846d7beff599f;
extern _jc_method _jc_polyglot_ext_jl_ast_Ext__5fc$method_info$init$ee9f9a61758512fe;
extern _jc_method _jc_polyglot_ext_jl_ast_Ext__5fc$method_info$node$d01193f9f5e593ba;
extern _jc_method _jc_polyglot_ext_jl_ast_Ext__5fc$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_Ext__5fc$vmethods {
	struct _jc_java_lang_Object$object	*(*copy$2119f530248e04c9)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *);
	struct _jc_object	*(*ext$8696abb67847e2d8)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *);
	struct _jc_object	*(*ext$7f9846d7beff599f)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *, struct _jc_object *);
	void	(*init$ee9f9a61758512fe)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *, struct _jc_object *);
	struct _jc_object	*(*node$d01193f9f5e593ba)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *);
};

// Vtable
struct _jc_polyglot_ext_jl_ast_Ext__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Ext__5fc$vmethods	polyglot_ext_jl_ast_Ext__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_Ext__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_Ext__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_Ext__5fc$sub_refs {
	struct _jc_object	*node;
	struct _jc_object	*ext;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_Ext__5fc$refs {
    _jc_polyglot_ext_jl_ast_Ext__5fc$sub_refs	polyglot_ext_jl_ast_Ext__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_Ext__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_Ext__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Ext__5fc$sub_nonrefs	polyglot_ext_jl_ast_Ext__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_Ext__5fc$object {
	_jc_polyglot_ext_jl_ast_Ext__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_Ext__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_Ext__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_Ext__5fc$vtype _jc_polyglot_ext_jl_ast_Ext__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_Ext__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_Ext__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_Ext__5fc_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/ast/Ext__5fc.h <==
// public abstract class polyglot.ext.jl.ast.Ext_c

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5b47f28ee45bd40c polyglot_ext_jl_ast_Ext__5fc

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_jl_ast_Ext__5fc_H_
#define _JC_polyglot_ext_jl_ast_Ext__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Ext$object;
struct _jc_polyglot_ast_Node$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_Ext__5fc$sub_refs	_jc_polyglot_ext_jl_ast_Ext__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_Ext__5fc$sub_nonrefs	_jc_polyglot_ext_jl_ast_Ext__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_Ext__5fc$refs	_jc_polyglot_ext_jl_ast_Ext__5fc$refs;
typedef struct _jc_polyglot_ext_jl_ast_Ext__5fc$nonrefs	_jc_polyglot_ext_jl_ast_Ext__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_Ext__5fc$object	_jc_polyglot_ext_jl_ast_Ext__5fc$object;

typedef const struct _jc_polyglot_ext_jl_ast_Ext__5fc$vmethods	_jc_polyglot_ext_jl_ast_Ext__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_Ext__5fc$vtable	_jc_polyglot_ext_jl_ast_Ext__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_Ext__5fc$vtype	_jc_polyglot_ext_jl_ast_Ext__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_Ext__5fc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_ast_Ext__5fc$method$_init$35a4291096b596b0(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_ext_jl_ast_Ext__5fc$method$copy$2119f530248e04c9(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_Ext__5fc$method$ext$8696abb67847e2d8(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_Ext__5fc$method$ext$7f9846d7beff599f(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_ast_Ext__5fc$method$init$ee9f9a61758512fe(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_Ext__5fc$method$node$d01193f9f5e593ba(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_ast_Ext__5fc$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_ast_Ext__5fc$method_info$copy$2119f530248e04c9;
extern _jc_method _jc_polyglot_ext_jl_ast_Ext__5fc$method_info$ext$8696abb67847e2d8;
extern _jc_method _jc_polyglot_ext_jl_ast_Ext__5fc$method_info$ext$7f9846d7beff599f;
extern _jc_method _jc_polyglot_ext_jl_ast_Ext__5fc$method_info$init$ee9f9a61758512fe;
extern _jc_method _jc_polyglot_ext_jl_ast_Ext__5fc$method_info$node$d01193f9f5e593ba;
extern _jc_method _jc_polyglot_ext_jl_ast_Ext__5fc$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_Ext__5fc$vmethods {
	struct _jc_java_lang_Object$object	*(*copy$2119f530248e04c9)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*ext$8696abb67847e2d8)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*ext$7f9846d7beff599f)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*init$ee9f9a61758512fe)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*node$d01193f9f5e593ba)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_ast_Ext__5fc$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_ast_Ext__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Ext__5fc$vmethods	polyglot_ext_jl_ast_Ext__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_Ext__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_Ext__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_Ext__5fc$sub_refs {
	struct _jc_object	*node;
	struct _jc_object	*ext;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_Ext__5fc$refs {
    _jc_polyglot_ext_jl_ast_Ext__5fc$sub_refs	polyglot_ext_jl_ast_Ext__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_Ext__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_Ext__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Ext__5fc$sub_nonrefs	polyglot_ext_jl_ast_Ext__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_Ext__5fc$object {
	_jc_polyglot_ext_jl_ast_Ext__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_Ext__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_Ext__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_Ext__5fc$vtype _jc_polyglot_ext_jl_ast_Ext__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_Ext__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_Ext__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_Ext__5fc_H_ */
